@@ -31,7 +31,6 @@
 #endif
 
 #include "tracker-monitor.h"
-#include "tracker-marshal.h"
 
 #define TRACKER_MONITOR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TRACKER_TYPE_MONITOR, TrackerMonitorPrivate))
 
@@ -160,7 +159,7 @@ tracker_monitor_class_init (TrackerMonitorClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              0,
 		              NULL, NULL,
-		              tracker_marshal_VOID__OBJECT_BOOLEAN,
+		              NULL,
 		              G_TYPE_NONE,
 		              2,
 		              G_TYPE_OBJECT,
@@ -171,7 +170,7 @@ tracker_monitor_class_init (TrackerMonitorClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              0,
 		              NULL, NULL,
-		              tracker_marshal_VOID__OBJECT_BOOLEAN,
+		              NULL,
 		              G_TYPE_NONE,
 		              2,
 		              G_TYPE_OBJECT,
@@ -182,7 +181,7 @@ tracker_monitor_class_init (TrackerMonitorClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              0,
 		              NULL, NULL,
-		              tracker_marshal_VOID__OBJECT_BOOLEAN,
+		              NULL,
 		              G_TYPE_NONE,
 		              2,
 		              G_TYPE_OBJECT,
@@ -193,7 +192,7 @@ tracker_monitor_class_init (TrackerMonitorClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              0,
 		              NULL, NULL,
-		              tracker_marshal_VOID__OBJECT_BOOLEAN,
+		              NULL,
 		              G_TYPE_NONE,
 		              2,
 		              G_TYPE_OBJECT,
@@ -204,7 +203,7 @@ tracker_monitor_class_init (TrackerMonitorClass *klass)
 		              G_SIGNAL_RUN_LAST,
 		              0,
 		              NULL, NULL,
-		              tracker_marshal_VOID__OBJECT_OBJECT_BOOLEAN_BOOLEAN,
+		              NULL,
 		              G_TYPE_NONE,
 		              4,
 		              G_TYPE_OBJECT,
@@ -282,7 +281,8 @@ tracker_monitor_init (TrackerMonitor *object)
 		name = g_type_name (priv->monitor_backend);
 
 		/* Set limits based on backend... */
-		if (strcmp (name, "GInotifyDirectoryMonitor") == 0) {
+		if (strcmp (name, "GInotifyDirectoryMonitor") == 0 ||
+		    strcmp (name, "GInotifyFileMonitor") == 0) {
 			/* Using inotify */
 			g_message ("Monitor backend is Inotify");
 
